@@ -1,3 +1,3 @@
 # errors for Mirador client
 # @author nickjacob (nick@mirador.im)
-from api import http_exceptions, MiradorException
+from api import *
